D365ServiceBase class

Implementers

Constructors

D365ServiceBase({required String tenantId, required String clientId, required String clientSecret, required String resource})

Properties

clientId String
final
clientSecret String
final
hashCode int
The hash code for this object.
no setterinherited
resource String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tenantId String
final

Methods

getAccessToken() Future<String?>
Retrieves an access token from Azure AD using the client credentials flow.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited