D365HttpClient class

Constructors

D365HttpClient(D365AuthService auth)

Properties

auth D365AuthService
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get<T>(String url, T parser(dynamic json)) Future<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(String url, Map<String, dynamic> body) Future<void>
post<T>(String url, Map<String, dynamic> body, T parser(dynamic json)) Future<T>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited