D365ApiService class
Methods
-
getAccessToken()
→ Future<String?>
-
Retrieves an access token from Azure AD using the client credentials flow.
inherited
-
getDropdownData({required String entity, required String valueField, required String displayField, String? filterByField, String? filterValue})
→ Future<List<Map<String, String>>>
-
Fetch dropdown data from a Dynamics 365 entity.
-
getEntityData({required String entity, String? filterByField, String? filterValue})
→ Future<List>
-
Retrieves data from a specified Dynamics 365 entity using an optional filter.
-
getEntityFieldsData({required String entity, List<String>? fields, String? keyField, String? keyValue})
→ Future<List>
-
Retrieves data from any Dynamics 365 entity as a list.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
postEntity(String entity, Map<String, dynamic> payload, {String? filterByField, String? filterValue, String? mainField})
→ Future<String?>
-
Sends a POST request to create a record in a Dynamics 365 entity.
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateEntity(String entity, Map<String, dynamic> payload, {required String keyField, required String keyValue})
→ Future<bool>
-
Sends a PATCH request to update an existing record in the specified Dynamics 365 entity.