D365ApiService class
Constructors
- D365ApiService(String resource, D365HttpClient client)
Properties
- client → D365HttpClient
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- resource → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createEntity(
String entity, Map< String, dynamic> payload) → Future<void> -
dropdown(
{required String entity, required String keyField, required String displayField}) → Future< List< DropdownItem> > -
getEntity(
String entity) → Future< List< Map< >String, dynamic> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateEntity(
String entity, String keyField, String keyValue, Map< String, dynamic> payload) → Future<void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited